# pybattletank

[![Release](https://img.shields.io/github/v/release/linhns/pybattletank)](https://img.shields.io/github/v/release/linhns/pybattletank)
[![Build status](https://img.shields.io/github/actions/workflow/status/linhns/pybattletank/main.yml?branch=main)](https://github.com/linhns/pybattletank/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/linhns/pybattletank)](https://img.shields.io/github/commit-activity/m/linhns/pybattletank)
[![License](https://img.shields.io/github/license/linhns/pybattletank)](https://img.shields.io/github/license/linhns/pybattletank)

BattleTank game using pygame
